@@ -20,7 +20,7 @@
 #include "asynccddblookuptest.h"
 #include "libkcddb/cache.h"
 #include "libkcddb/lookup.h"
-#include <QtTest/QTest>
+#include <QTest>
 
 void AsyncCDDBLookupTest::testLookup()
 {
